@@ -12,6 +12,9 @@
 #ifndef LIBC_MUSL
 # define LIBC_MUSL 4
 #endif
+#ifndef HEAP_TRAMPOLINES_INIT
+# define HEAP_TRAMPOLINES_INIT 0
+#endif
 #ifdef IN_GCC
 # include "options.h"
 # include "insn-constants.h"
@@ -20,12 +23,13 @@
 # include "config/i386/unix.h"
 # include "config/i386/bsd.h"
 # include "config/i386/gas.h"
-# include "config/dbxcoff.h"
 # include "config/i386/cygming.h"
 # include "config/i386/mingw-pthread.h"
-# include "config/i386/mingw32.h"
+# include "config/mingw/mingw32.h"
 # include "config/i386/mingw-w64.h"
-# include "config/i386/mingw-stdint.h"
+# include "config/mingw/mingw-stdint.h"
+# include "config/mingw/winnt.h"
+# include "config/mingw/winnt-dll.h"
 # include "config/initfini-array.h"
 # include "config/tm-dwarf2.h"
 #endif
